@@ -1,7 +1,10 @@
 package Unicode::Confuse::Parse;
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw/parse_confusables/;
+our @EXPORT_OK = qw/
+    metadata
+    parse_confusables
+/;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 use warnings;
 use strict;
@@ -9,7 +12,7 @@ use utf8;
 use Carp;
 use File::Slurper 'read_text';
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 # A code point
 my $cp = qr!([0-9A-F]{4,5})\s+!;
@@ -73,4 +76,44 @@ sub msg
     print ".\n";
 }
 
+# Extract the date and version information from the confusables
+# file. The return value is a hash reference which is then directly
+# converted to JSON.
+
+sub metadata
+{
+    my ($file) = @_;
+    if (! -f $file) {
+	die "No $file";
+    }
+    my %md;
+    my $text = read_text ($file);
+    while ($text =~ /^# (.*)$/gm) {
+	my $data = $1;
+	if ($data =~ /(Date|Version): (.*)/) {
+	    my $what = lc $1;
+	    $md{$what} = $2;
+	    next;
+	}
+	if ($data =~ /©/) {
+	    $md{copyright} = $data;
+	    next;
+	}
+	if ($data =~ /terms of use/i) {
+	    $md{terms} = $data;
+	    next;
+	}
+	if ($data =~ /Unicode Security Mechanisms/) {
+	    $md{title} = $data;
+	    next;
+	}
+	if ($data eq 'confusables.txt' ||
+	    $data =~ /trademark|documentation|total/) {
+	    next;
+	}
+	warn "Unparsed metadata line '$data' in $file.\n";
+    }
+    return \%md;
+}
+
 1;
